/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2007 Bull S.A.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ServerManagement.java 13396 2008-03-27 15:53:27Z fornacif $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.lib.management.tools;

import javax.management.ObjectName;

import org.ow2.jonas.lib.management.javaee.J2eeObjectName;


/**
 *
 */
public class ServerManagement {

    private final static String serverVersionAttribute = "serverVersion";

    private String serverName = null;
    private String domainName = null;

    public ServerManagement() {
        serverName = WhereAreYou.getServerName();
        domainName = WhereAreYou.getDomainName();
    }

    /**
     * @return The current server name.
     */
    public String getServerName() {
        return serverName;
    }

    /**
     * @return The current domain name.
     */
    public String getDomainName() {
        return domainName;
    }

    /**
     * Get the value of the "serverVersion" attribute of a server in a domain.
     * @param pServer server name.
     * @param pDomain domain name.
     * @return the "serverVersion" attribute of the corresponding J2EEServer MBean.
     */
    public String getServerVersion(final String pServer, final String pDomain) {
        ObjectName serverOn = J2eeObjectName.J2EEServer(pDomain, pServer);
        return (String) ManagementRepr.getAttribute(serverOn, serverVersionAttribute, pServer);
    }

    /**
     * Get the value of the "serverVersion" attribute of the current server.
     * @return the "serverVersion" attribute of the current server's J2EEServer MBean.
     */
    public String getServerVersion() {
        return getServerVersion(serverName, domainName);
    }
}
